@@ -34,13 +34,48 @@ defined('_JEXEC') or die('Restricted access');
 /**
  * Table class for question votes
  */
-class AnswersTableQuestionsLog extends JTable
+class AnswersQuestionsLog extends JTable
 {
+	/**
+	 * int(11) Primary key
+	 * 
+	 * @var integer
+	 */
+	var $id      = NULL;
+
+	/**
+	 * int(11)
+	 * 
+	 * @var integer
+	 */
+	var $qid     = NULL;
+
+	/**
+	 * datetime (0000-00-00 00:00:00)
+	 * 
+	 * @var unknown
+	 */
+	var $expires = NULL;
+
+	/**
+	 * int(11)
+	 * 
+	 * @var integer
+	 */
+	var $voter   = NULL;
+
+	/**
+	 * varchar(15)
+	 * 
+	 * @var string
+	 */
+	var $ip      = NULL;
+
 	/**
 	 * Constructor
-	 *
-	 * @param   object  &$db  JDatabase
-	 * @return  void
+	 * 
+	 * @param      object &$db JDatabase
+	 * @return     void
 	 */
 	public function __construct(&$db)
 	{
@@ -49,69 +84,50 @@ class AnswersTableQuestionsLog extends JTable
 
 	/**
 	 * Validate data
-	 *
-	 * @return  boolean  True if data is valid
+	 * 
+	 * @return     boolean True if data is valid
 	 */
 	public function check()
 	{
-		$this->question_id = intval($this->question_id);
-		if (!$this->question_id)
+		if (trim($this->qid) == '') 
 		{
 			$this->setError(JText::_('Missing question ID'));
 			return false;
 		}
-
-		$this->voter = intval($this->voter);
-		if (!$this->voter)
-		{
-			$this->voter = JFactory::getUser()->get('id');
-		}
-
-		if (!$this->expires)
-		{
-			$this->expires = JFactory::getDate(time() + (7 * 24 * 60 * 60))->toSql(); // in a week
-		}
-
-		if (!\Hubzero\Utility\Validate::ip($this->ip))
-		{
-			$this->setError(JText::_('Invalid IP address'));
-			return false;
-		}
-
 		return true;
 	}
 
 	/**
 	 * Check if a user has voted
-	 *
-	 * @param   integer  $qid    Question ID
-	 * @param   string   $ip     IP address
-	 * @param   integer  $voter  Voter user ID
-	 * @return  mixed    False if error, integer on success
+	 * 
+	 * @param      integer $qid   Question ID
+	 * @param      string  $ip    IP address
+	 * @param      integer $voter Voter user ID
+	 * @return     mixed False if error, integer on success
 	 */
 	public function checkVote($qid=null, $ip=null, $voter=null)
 	{
-		if ($qid == null)
+		if ($qid == null) 
 		{
-			$qid = $this->question_id;
+			$qid = $this->qid;
 		}
-		if ($qid == null)
+		if ($qid == null) 
 		{
 			return false;
 		}
 
-		$now = JFactory::getDate()->toSql();
+		$now = date('Y-m-d H:i:s', time());
 
-		$query = "SELECT COUNT(*) FROM `$this->_tbl` WHERE question_id=" . $this->_db->Quote($qid);
 		if ($voter !== null)
 		{
-			$query .= " AND voter=" . $this->_db->Quote($voter);
+			$and = " AND voter='" . $voter . "'";
 		}
 		else
 		{
-			$query .= " AND ip=" . $this->_db->Quote($ip);
+			$and = " AND ip='" . $ip . "'";
 		}
 
+		$query = "SELECT count(*) FROM $this->_tbl WHERE qid='" . $qid . "'" . $and;
 
 		$this->_db->setQuery($query);
 		return $this->_db->loadResult();
