@@ -111,7 +111,7 @@ class plgGroupsBulletinboard extends JPlugin
 			$group_plugin_acl = $access[$active];
 
 			//Create user object
-			$juser = JFactory::getUser();
+			$juser =& JFactory::getUser();
 
 			//get the group members
 			$members = $group->get('members');
@@ -164,6 +164,22 @@ class plgGroupsBulletinboard extends JPlugin
 			ximport('Hubzero_Document');
 			Hubzero_Document::addPluginStylesheet('groups', $this->_name);
 
+			$this->dateFormat  = '%d %b, %Y';
+			$this->timeFormat  = '%I:%M %p';
+			$this->monthFormat = '%b';
+			$this->yearFormat  = '%Y';
+			$this->dayFormat   = '%d';
+			$this->tz = 0;
+			if (version_compare(JVERSION, '1.6', 'ge'))
+			{
+				$this->dateFormat  = 'd M, Y';
+				$this->timeFormat  = 'h:i a';
+				$this->monthFormat = 'b';
+				$this->yearFormat  = 'Y';
+				$this->dayFormat   = 'd';
+				$this->tz = true;
+			}
+
 			//include helpers
 			//include_once(JPATH_ROOT . DS . 'components' . DS . 'com_whiteboard' . DS . 'tables' . DS . 'whiteboard.comment.php');
 			//include_once(JPATH_ROOT . DS . 'components' . DS . 'com_whiteboard' . DS . 'helpers' . DS . 'whiteboard.member.php');
@@ -212,7 +228,7 @@ class plgGroupsBulletinboard extends JPlugin
 		$filters['scope']    = 'group';
 		$filters['group_id'] = $group->get('gidNumber');
 
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$filters['state'] = 'public';
@@ -257,6 +273,12 @@ class plgGroupsBulletinboard extends JPlugin
 		$view->config     = $this->params;
 		$view->authorized = $this->authorized;
 
+		$view->dateFormat  = $this->dateFormat;
+		$view->timeFormat  = $this->timeFormat;
+		$view->yearFormat  = $this->yearFormat;
+		$view->monthFormat = $this->monthFormat;
+		$view->dayFormat   = $this->dayFormat;
+		$view->tz          = $this->tz;
 		$view->canpost = true;
 
 		Hubzero_Document::addPluginScript('groups', $this->_name, 'jquery.masonry');
@@ -276,7 +298,7 @@ class plgGroupsBulletinboard extends JPlugin
 
 		/*$view->canpost = $this->_getPostingPermissions();
 
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$filters['state'] = 'public';
@@ -411,13 +433,20 @@ class plgGroupsBulletinboard extends JPlugin
 		$view->authorized = $this->authorized;
 		$view->juser = $this->juser;
 
+		$view->dateFormat  = $this->dateFormat;
+		$view->timeFormat  = $this->timeFormat;
+		$view->yearFormat  = $this->yearFormat;
+		$view->monthFormat = $this->monthFormat;
+		$view->dayFormat   = $this->dayFormat;
+		$view->tz          = $this->tz;
+
 		if (isset($this->entry) && is_object($this->entry)) 
 		{
 			$view->row = $this->entry;
 		} 
 		else 
 		{
-			$juri = JURI::getInstance();
+			$juri =& JURI::getInstance();
 			$path = $juri->getPath();
 			if (strstr($path, '/')) 
 			{
@@ -436,7 +465,7 @@ class plgGroupsBulletinboard extends JPlugin
 		}
 
 		// Check authorization
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if (($view->row->state == 2 && $juser->get('guest'))
 		 || ($view->row->state == 0 && $juser->get('id') != $view->row->created_by && $this->authorized != 'member' && $this->authorized != 'manager' && $this->authorized != 'admin')) 
 		{
@@ -444,7 +473,7 @@ class plgGroupsBulletinboard extends JPlugin
 			return;
 		}
 
-		//$juser = JFactory::getUser();
+		//$juser =& JFactory::getUser();
 		if ($juser->get('id') != $view->row->created_by) 
 		{
 			$view->row->hit();
@@ -453,7 +482,7 @@ class plgGroupsBulletinboard extends JPlugin
 		if ($view->row->content) 
 		{
 			ximport('Hubzero_Wiki_Parser');
-			$p = Hubzero_Wiki_Parser::getInstance();
+			$p =& Hubzero_Wiki_Parser::getInstance();
 
 			if ($view->row->scope == 'member') 
 			{
@@ -541,7 +570,7 @@ class plgGroupsBulletinboard extends JPlugin
 		$view->recent = $view->row->getRecentEntries($filters);
 
 		// Push some scripts to the template
-		/*$document = JFactory::getDocument();
+		/*$document =& JFactory::getDocument();
 		if (is_file(JPATH_ROOT . DS . 'plugins' . DS . 'groups' . DS . 'whiteboard' . DS . 'whiteboard.js')) {
 			$document->addScript('plugins' . DS . 'groups' . DS . 'whiteboard' . DS . 'whiteboard.js');
 		}*/
@@ -577,8 +606,8 @@ class plgGroupsBulletinboard extends JPlugin
 	 */
 	private function _edit()
 	{
-		$juser = JFactory::getUser();
-		$app = JFactory::getApplication();
+		$juser =& JFactory::getUser();
+		$app =& JFactory::getApplication();
 
 		$board = JRoute::_('index.php?option=' . $this->option . '&gid=' . $this->group->get('cn') . '&active=bulletinboard');
 		if ($juser->get('guest')) 
@@ -639,6 +668,13 @@ class plgGroupsBulletinboard extends JPlugin
 		$view->config     = $this->params;
 		$view->authorized = $this->authorized;
 
+		$view->dateFormat  = $this->dateFormat;
+		$view->timeFormat  = $this->timeFormat;
+		$view->yearFormat  = $this->yearFormat;
+		$view->monthFormat = $this->monthFormat;
+		$view->dayFormat   = $this->dayFormat;
+		$view->tz          = $this->tz;
+
 		$id = JRequest::getInt('entry', 0);
 
 		$view->entry = new BulletinboardBulletin($this->database);
@@ -685,7 +721,7 @@ class plgGroupsBulletinboard extends JPlugin
 	 */
 	private function _save()
 	{
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
@@ -760,7 +796,7 @@ class plgGroupsBulletinboard extends JPlugin
 		$bt = new BulletinboardTags($this->database);
 		$bt->tag_object($juser->get('id'), $row->id, $tags, 1, 1);
 
-		$app = JFactory::getApplication();
+		$app =& JFactory::getApplication();
 		$app->redirect(JRoute::_('index.php?option=com_groups&gid=' . $this->group->get('cn') . '&active=' . $this->_name));
 	}
 
@@ -883,7 +919,7 @@ class plgGroupsBulletinboard extends JPlugin
 	 */
 	/*private function _delete()
 	{
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
@@ -940,6 +976,13 @@ class plgGroupsBulletinboard extends JPlugin
 			$view->entry = $entry;
 			$view->authorized = $this->authorized;
 			
+			$view->dateFormat  = $this->dateFormat;
+			$view->timeFormat  = $this->timeFormat;
+			$view->yearFormat  = $this->yearFormat;
+			$view->monthFormat = $this->monthFormat;
+			$view->dayFormat   = $this->dayFormat;
+			$view->tz          = $this->tz;
+			
 			if ($this->getError()) 
 			{
 				foreach ($this->getErrors() as $error)
@@ -968,7 +1011,7 @@ class plgGroupsBulletinboard extends JPlugin
 	/*private function _savecomment()
 	{
 		// Ensure the user is logged in
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
@@ -989,7 +1032,7 @@ class plgGroupsBulletinboard extends JPlugin
 		// Set the created time
 		if (!$row->id) 
 		{
-			$row->created = JFactory::getDate()->toSql();
+			$row->created = date('Y-m-d H:i:s', time());  // use gmdate() ?
 		}
 
 		// Check content
@@ -1017,7 +1060,7 @@ class plgGroupsBulletinboard extends JPlugin
 	/*private function _deletecomment()
 	{
 		// Ensure the user is logged in
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
@@ -1132,7 +1175,7 @@ class plgGroupsBulletinboard extends JPlugin
 	private function _upload($files, $listdir, $type, $descriptions)
 	{
 		// Ensure the user is logged in
-		$juser = JFactory::getUser();
+		$juser =& JFactory::getUser();
 		if ($juser->get('guest')) 
 		{
 			$this->setError(JText::_('GROUPS_LOGIN_NOTICE'));
@@ -1153,7 +1196,7 @@ class plgGroupsBulletinboard extends JPlugin
 		if (!is_dir($path)) 
 		{
 			jimport('joomla.filesystem.folder');
-			if (!JFolder::create($path)) 
+			if (!JFolder::create($path, 0777)) 
 			{
 				$this->setError(JText::_('Error uploading. Unable to create path.'));
 				return false;
