@@ -32,11 +32,12 @@
 defined('_JEXEC') or die('Restricted access');
 
 jimport('joomla.plugin.plugin');
+ximport('Hubzero_Plugin');
 
 /**
  * Groups Plugin class for messages
  */
-class plgGroupsMessages extends JPlugin
+class plgGroupsMessages extends Hubzero_Plugin
 {
 	/**
 	 * Constructor
@@ -134,10 +135,10 @@ class plgGroupsMessages extends JPlugin
 			if ($juser->get('guest') 
 			 && ($group_plugin_acl == 'registered' || $group_plugin_acl == 'members')) 
 			{
-				ximport('Hubzero_Module_Helper');
-				$arr['html']  = '<p class="info">' . JText::sprintf('GROUPS_PLUGIN_REGISTERED', ucfirst($active)) . '</p>';
-				$arr['html'] .= Hubzero_Module_Helper::renderModules('force_mod');
-				return $arr;
+				$url = JRoute::_('index.php?option=com_groups&cn='.$group->get('cn').'&active='.$active);
+				$message = JText::sprintf('GROUPS_PLUGIN_REGISTERED', ucfirst($active));
+				$this->redirect( "/login?return=".base64_encode($url), $message, 'warning' );
+				return;
 			}
 
 			//check to see if user is member and plugin access requires members
